Struct Bindings
pub struct Bindings { /* private fields */ }
Generated Rust bindings.
Implementations
impl Bindings
fn write_to_file<P: AsRef<Path>>(&self, path: P) -> Result<()>Write these bindings as source text to a file.
fn write<'a>(&self, writer: Box<dyn Write + 'a>) -> Result<()>Write these bindings as source text to the given
Writeable.