Struct RustTarget
struct RustTarget(_)
Represents the version of the Rust language to target.
Implementations
impl RustTarget
const fn nightly() -> SelfThe nightly version of Rust, which introduces the following features:"
impl RustTarget
fn stable(minor: u64, patch: u64) -> Result<Self, InvalidRustTarget>Create a new
RustTargetfor a stable release of Rust.
impl Clone for RustTarget
fn clone(self: &Self) -> RustTarget
impl Copy for RustTarget
impl Debug for RustTarget
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for RustTarget
fn default() -> Self
impl Display for RustTarget
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for RustTarget
impl Freeze for RustTarget
impl FromStr for RustTarget
fn from_str(input: &str) -> Result<Self, <Self as >::Err>
impl Hash for RustTarget
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for RustTarget
fn cmp(self: &Self, other: &RustTarget) -> Ordering
impl PartialEq for RustTarget
fn eq(self: &Self, other: &RustTarget) -> bool
impl PartialOrd for RustTarget
fn partial_cmp(self: &Self, other: &RustTarget) -> Option<Ordering>
impl RefUnwindSafe for RustTarget
impl Send for RustTarget
impl StructuralPartialEq for RustTarget
impl Sync for RustTarget
impl Unpin for RustTarget
impl UnsafeUnpin for RustTarget
impl UnwindSafe for RustTarget
impl<T> Any for RustTarget
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RustTarget
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RustTarget
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for RustTarget
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for RustTarget
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for RustTarget
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for RustTarget
fn to_string(self: &Self) -> String
impl<T, U> Into for RustTarget
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RustTarget
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RustTarget
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>