Module bindgen::callbacks [−][src]
A public API for more fine-grained customization of bindgen behavior.
Enums
| EnumVariantCustomBehavior |
An enum representing custom handling that can be given to a variant. |
| EnumVariantValue |
A constant value assigned to an enumeration variant. |
| IntKind |
Which integral type are we dealing with? |
| MacroParsingBehavior |
An enum to allow ignoring parsing of macros. |
Traits
| ParseCallbacks |
A trait to allow configuring different kinds of types in different situations. |